@@ -1,5 +1,3 @@
-const { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-
 function run_test() {
   var notifications = 0;
   var obs = {
@@ -8,9 +6,9 @@ function run_test() {
       notifications++;
     },
   };
-  Services.os.addObserver(obs, "last-pb-context-exited");
+  Services.obs.addObserver(obs, "last-pb-context-exited");
 
-  run_test_in_child("../unit/test_pb_notification.js", function() {
+  run_test_in_child("../unit/test_pb_notification.js", function () {
     Assert.equal(notifications, 1);
     do_test_finished();
   });
